@@ -28,7 +28,7 @@ setClass(
 #'
 #' In the TRAMO-SEATS method, the second step - SEATS ("Signal Extraction in ARIMA Time Series") - performs
 #' an ARIMA-based decomposition of an observed time series into unobserved components.
-#' More information on the method can be found on the Bank of Spain website (\url{https://www.bde.es}).
+#' More information on the method can be found on the Bank of Spain website (\url{https://www.bde.es/bde/es/}).
 #'
 #' The available predefined 'JDemetra+' TRAMO-SEATS model specifications are described in the table below:
 
@@ -85,7 +85,7 @@ setClass(
 #'
 #' @references
 #' Info on 'JDemetra+', usage and functions:
-#' \url{https://ec.europa.eu/eurostat/cros/content/documentation_en}
+#' \url{https://ec.europa.eu/eurostat/cros/content/documentation_en/}
 #'
 #' BOX G.E.P. and JENKINS G.M. (1970), "Time Series Analysis: Forecasting and Control", Holden-Day, San Francisco.
 #'
@@ -149,11 +149,17 @@ tramoseats.SA_spec <- function(series, spec,
   }else{
 
     # Error during the preliminary check
-    if(is.null(jrslt$getDiagnostics()) & !jrslt$getResults()$getProcessingInformation()$isEmpty()){
+    res = jrslt$getResults()$getProcessingInformation()
+
+    if(is.null(jrslt$getDiagnostics()) & !.jcall(res,"Z","isEmpty")){
       proc_info <- jrslt$getResults()$getProcessingInformation()
-      error_msg <- proc_info$get(0L)$getErrorMessages(proc_info)
-      if(!error_msg$isEmpty())
+
+      error_msg <- .jcall(proc_info, "Ljava/lang/Object;", "get", 0L)$getErrorMessages(proc_info)
+      warning_msg <- .jcall(proc_info, "Ljava/lang/Object;", "get", 0L)$getWarningMessages(proc_info)
+      if(!.jcall(error_msg,"Z","isEmpty"))
         stop(error_msg$toString())
+      if(!.jcall(warning_msg,"Z","isEmpty"))
+        warning(warning_msg$toString())
     }
     reg <- regarima_TS(jrobj = jrobct_arima, spec = spec$regarima)
     deco <- decomp_TS(jrobj = jrobct, spec = spec$seats)
@@ -191,11 +197,16 @@ tramoseatsJavaResults <- function(jrslt, spec,
     return(NaN)
 
   # Error in preliminary check
-  if(is.null(jrslt$getDiagnostics()) & !jrslt$getResults()$getProcessingInformation()$isEmpty()){
+  res = jrslt$getResults()$getProcessingInformation()
+
+  if(is.null(jrslt$getDiagnostics()) & !.jcall(res,"Z","isEmpty")){
     proc_info <- jrslt$getResults()$getProcessingInformation()
-    error_msg <- proc_info$get(0L)$getErrorMessages(proc_info)
-    if(!error_msg$isEmpty())
+    error_msg <- .jcall(proc_info, "Ljava/lang/Object;", "get", 0L)$getErrorMessages(proc_info)
+    warning_msg <- .jcall(proc_info, "Ljava/lang/Object;", "get", 0L)$getWarningMessages(proc_info)
+    if(!.jcall(error_msg,"Z","isEmpty"))
       stop(error_msg$toString())
+    if(!.jcall(warning_msg,"Z","isEmpty"))
+      warning(warning_msg$toString())
   }
 
   reg <- regarima_defTS(jrobj = jrobct_arima, spec = spec,
